Stan Math Library: stan/math/prim/arr/functor/coupled_ode_system.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Classes | Namespaces
coupled_ode_system.hpp File Reference
`#include <stan/math/prim/scal/err/check_size_match.hpp>`
`#include <ostream>`
`#include <vector>`

Go to the source code of this file.

## Classes
struct | stan::math::coupled_ode_system< F, T1, T2 >
| Base template class for a coupled ordinary differential equation system, which adds sensitivities to the base system. More...
class | stan::math::coupled_ode_system< F, double, double >
| The coupled ode system for known initial values and known parameters. More...

## Namespaces
| stan
| stan::math
| Matrices and templated mathematical functions.

[ Stan Home Page ] © 2011–2016, Stan Development Team.